## 0.4.2 - 2022-12-20

### Changed

- [#642](https://github.com/edgarrmondragon/citric/issues/642) Remove upper bound constrain on `importlib-metadata`

### Fixed

- [#643](https://github.com/edgarrmondragon/citric/issues/643) Fixed a few type annotations
